Crate miden_validator

Crate miden_validator 

Re-exports

pub use data_directory::DataDirectory;

Modules

data_directory
db

Structs

EncodedGoldenOperatorKey
Canonical Golden values needed to restore one validator operator key.
GoldenOperatorKey
Validated Golden material held by one validator operator.
KmsSigner
Block signer that uses AWS KMS to create signatures.
LocalX25519TransactionInputDecrypter
TransactionInputDecrypter backed by a locally provisioned X25519 shared secret.
PrivateRecordChainId
Identifier for the chain that owns a private record.
PrivateRecordCombiner
Public Golden setup used to verify shares and open private records.
PrivateRecordContext
Values bound to one private record and its Golden decryption shares.
PrivateRecordId
Global identity of one validator’s encrypted record for a transaction.
PrivateRecordSealer
Public Golden key used to seal private records for one epoch.
PrivateRecordShareRequest
Exact record values that an operator must approve before issuing a share.
PrivateRecordStorageFields
Database fields for one versioned private record.
StorageKeyEpoch
Identifier for one version of the validator storage key.
StoredPrivateRecord
Versioned encrypted private record stored by the validator.
ValidatorAdminServer
Serves the private validator administration API on a network-isolated listener.
ValidatorServer
The handle into running the gRPC validator server.

Enums

GoldenOperatorKeyError
Error raised while loading a Golden operator key.
PrivateRecordError
Error raised while sealing or reading a private record.
PrivateRecordFormatVersion
Supported private record formats.
ValidatorSigner
Signer that the Validator uses to sign blocks.

Constants

COMPONENT
The name of the validator component.
LOG_TARGET
The target to use for user-visible events.

Traits

TransactionInputDecrypter
Decryption counterpart to ValidatorSigner for the shared transaction encryption (submission) key.

Functions

decrypt_key_material
Recovers key material wrapped with an AWS KMS key by calling kms:Decrypt.