pub async fn load(
database_filepath: PathBuf,
) -> Result<ValidatorDbWriter, DatabaseError>Expand description
Opens a connection pool after verifying that the database is at the latest schema version.
pub async fn load(
database_filepath: PathBuf,
) -> Result<ValidatorDbWriter, DatabaseError>Opens a connection pool after verifying that the database is at the latest schema version.