pub struct PrivateRecordStorageFields {
pub record_id: PrivateRecordId,
pub context: PrivateRecordContext,
pub setup_context_id: [u8; 32],
pub nonce: Vec<u8>,
pub encrypted_record: Vec<u8>,
pub encrypted_record_key: Vec<u8>,
}Expand description
Database fields for one versioned private record.
Fields
record_id: PrivateRecordIdOperational identity used to find and export the record.
context: PrivateRecordContextValues bound into both encryption layers, including the record format version.
setup_context_id: [u8; 32]Golden setup context identifier.
nonce: Vec<u8>Public record cipher nonce.
encrypted_record: Vec<u8>Authenticated record ciphertext.
encrypted_record_key: Vec<u8>Canonical Golden ciphertext for the content key.