Skip to main contentModule db
Source - ValidatorDbReader
- Read-only handle to the validator database.
- ValidatorDbWriter
- Write handle to the validator database.
- bootstrap
- Creates and initializes the database, then seeds it with the genesis block header as the chain
tip.
- load
- Opens a connection pool after verifying that the database is at the latest schema version.
- load_with_pool_size
- Opens a connection pool with a specific pool size after verifying that the database is at the
latest schema version.
- migrate
- Applies all pending migrations to an existing DB.
- setup
- Creates a new database, applies all migrations, and opens a connection pool.