pub async fn load(database_filepath: PathBuf) -> Result<Db, DatabaseError>Expand description
Open a connection to the DB after verifying that it is at the latest schema version.
pub async fn load(database_filepath: PathBuf) -> Result<Db, DatabaseError>Open a connection to the DB after verifying that it is at the latest schema version.