pub enum PrivateRecordError {
Show 17 variants
KeyEpochMismatch,
RecordIdMismatch,
InvalidValidatorId(DeserializationError),
SetupContextMismatch,
DecryptionContextMismatch,
RecordEncryption,
ContentKeyEncryption(Error),
InvalidGoldenEncoding(Error),
InvalidCombinerSetup(Error),
InvalidDecryptionShare(Error),
ShareGeneration(Error),
ShareCombination(CombineError),
InvalidEncryptedRecordKey,
UnsupportedFormat(u32),
InvalidNonceLength {
actual: usize,
},
InvalidRecordCiphertext,
RecordDecryption,
}Expand description
Error raised while sealing or reading a private record.
Variants
KeyEpochMismatch
The record, request, and active storage key name different epochs.
RecordIdMismatch
The share request names a different private record.
InvalidValidatorId(DeserializationError)
The validator identity is not a canonical signing public key.
SetupContextMismatch
The operator and record name different Golden setups.
DecryptionContextMismatch
The request does not carry the record’s exact canonical context.
RecordEncryption
The authenticated record cipher failed.
ContentKeyEncryption(Error)
Golden failed to seal the content key.
InvalidGoldenEncoding(Error)
The canonical Golden value could not be decoded or verified.
InvalidCombinerSetup(Error)
The public Golden setup cannot create a combiner.
A canonical decryption share could not be decoded.
Golden could not issue a decryption share.
Golden rejected the provided share set.
InvalidEncryptedRecordKey
The Golden ciphertext does not wrap a content key of the expected size.
UnsupportedFormat(u32)
The stored record format is not supported.
InvalidNonceLength
The stored nonce has the wrong size.
InvalidRecordCiphertext
The stored record ciphertext cannot contain an authentication tag.
RecordDecryption
The authenticated record cipher rejected the content key, context, or ciphertext.